==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/Effect/filewriter/translations/filewriter_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>EffectFileWriterFactory</name>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="30"/>
        <source>File Writer Plugin</source>
        <translation>文件写入插件</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="51"/>
        <source>About File Writer Plugin</source>
        <translation>关于文件写入插件</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="52"/>
        <source>Qmmp File Writer Plugin</source>
        <translation>Qmmp 文件写入插件</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Writer Plugin Settings</source>
        <translation>文件写入插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Output directory:</source>
        <translation>输出文件夹：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>Output file name:</source>
        <translation>输入文档名称：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Quality:</source>
        <translation>质量：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="69"/>
        <source>Choose a directory</source>
        <translation>选择文件夹</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/Effect/filewriter/translations/filewriter_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>EffectFileWriterFactory</name>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="30"/>
        <source>File Writer Plugin</source>
        <translation>文件写入插件</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="50"/>
        <source>About File Writer Plugin</source>
        <translation>关于文件写入插件</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="51"/>
        <source>Qmmp File Writer Plugin</source>
        <translation>Qmmp 文件写入插件</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileWriterSettingsDialog</name>
    <message>
        <location filename="../filewritersettingsdialog.ui" line="14"/>
        <source>File Writer Plugin Settings</source>
        <translation>文件写入插件设置</translation>
    </message>
    <message>
        <location filename="../filewritersettingsdialog.ui" line="29"/>
        <source>Output directory:</source>
        <translation>输出文件夹：</translation>
    </message>
    <message>
        <location filename="../filewritersettingsdialog.ui" line="36"/>
        <source>Quality:</source>
        <translation>质量：</translation>
    </message>
    <message>
        <location filename="../filewritersettingsdialog.ui" line="95"/>
        <source>Output file name:</source>
        <translation>输入文档名称：</translation>
    </message>
    <message>
        <location filename="../filewritersettingsdialog.ui" line="109"/>
        <source>Write to single file if possible.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filewritersettingsdialog.cpp" line="72"/>
        <source>Choose a directory</source>
        <translation>选择文件夹</translation>
    </message>
</context>
</TS>
